@@ -13,6 +13,7 @@ from collections import defaultdict
 from typing import NoReturn, Union
 
 from hypothesis import Verbosity, settings
+from hypothesis._settings import note_deprecation
 from hypothesis.errors import InvalidArgument, UnsatisfiedAssumption
 from hypothesis.internal.compat import BaseExceptionGroup
 from hypothesis.internal.conjecture.data import ConjectureData
@@ -24,7 +25,13 @@ from hypothesis.vendor.pretty import IDKey
 
 
 def reject() -> NoReturn:
-    raise UnsatisfiedAssumption()
+    if _current_build_context.value is None:
+        note_deprecation(
+            "Using `reject` outside a property-based test is deprecated",
+            since="2023-09-25",
+            has_codemod=False,
+        )
+    raise UnsatisfiedAssumption
 
 
 def assume(condition: object) -> bool:
@@ -34,8 +41,14 @@ def assume(condition: object) -> bool:
     This allows you to specify properties that you *assume* will be
     true, and let Hypothesis try to avoid similar examples in future.
     """
+    if _current_build_context.value is None:
+        note_deprecation(
+            "Using `assume` outside a property-based test is deprecated",
+            since="2023-09-25",
+            has_codemod=False,
+        )
     if not condition:
-        raise UnsatisfiedAssumption()
+        raise UnsatisfiedAssumption
     return True
 
 
@@ -62,7 +75,7 @@ def current_build_context() -> "BuildContext":
 
 
 class BuildContext:
-    def __init__(self, data, is_final=False, close_on_capture=True):
+    def __init__(self, data, *, is_final=False, close_on_capture=True):
         assert isinstance(data, ConjectureData)
         self.data = data
         self.tasks = []
